summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorKristian Høgsberg <krh@bitplanet.net>2010-07-02 11:50:01 -0400
committerKristian Høgsberg <krh@bitplanet.net>2010-07-02 12:20:59 -0400
commit3f0034a990acfa3587c975306a37f7b455fb3d62 (patch)
treeef25b2145c83d8633f66cc790a5e05768b3be289 /include
parent5669e1a82d24af8ebb6653f75a80f8b11279a6fc (diff)
downloadxorg-lib-libxkbcommon-3f0034a990acfa3587c975306a37f7b455fb3d62.tar.gz
Rename public entry points to lowercase and underscore
Diffstat (limited to 'include')
-rw-r--r--include/X11/extensions/XKBcommon.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/include/X11/extensions/XKBcommon.h b/include/X11/extensions/XKBcommon.h
index 59a0dd4..b657501 100644
--- a/include/X11/extensions/XKBcommon.h
+++ b/include/X11/extensions/XKBcommon.h
@@ -885,19 +885,19 @@ typedef uint32_t (*InternAtomFuncPtr)(const char *val);
typedef const char *(*GetAtomValueFuncPtr)(uint32_t atom);
_X_EXPORT extern void
-XkbcInitAtoms(InternAtomFuncPtr intern, GetAtomValueFuncPtr get_atom_value);
+xkb_init_atoms(InternAtomFuncPtr intern, GetAtomValueFuncPtr get_atom_value);
_X_EXPORT extern struct xkb_desc *
-XkbcCompileKeymapFromRules(const XkbRMLVOSet *rmlvo);
+xkb_compile_keymap_from_rules(const XkbRMLVOSet *rmlvo);
_X_EXPORT extern struct xkb_desc *
-XkbcCompileKeymapFromComponents(const struct xkb_component_names * ktcsg);
+xkb_compile_keymap_from_components(const struct xkb_component_names * ktcsg);
_X_EXPORT extern struct xkb_desc *
-XkbcCompileKeymapFromFile(FILE *inputFile, const char *mapName);
+xkb_compile_keymap_from_file(FILE *inputFile, const char *mapName);
_X_EXPORT extern struct xkb_component_list *
-XkbcListComponents(struct xkb_component_names * ptrns, int *maxMatch);
+xkb_list_components(struct xkb_component_names * ptrns, int *maxMatch);
/*
* Canonicalises component names by prepending the relevant component from
@@ -914,7 +914,7 @@ XkbcListComponents(struct xkb_component_names * ptrns, int *maxMatch);
* free()d, and a new one allocated with malloc().
*/
_X_EXPORT extern void
-XkbcCanonicaliseComponents(struct xkb_component_names * names,
+xkb_canonicalise_components(struct xkb_component_names * names,
const struct xkb_component_names * old);
/*
@@ -922,21 +922,21 @@ XkbcCanonicaliseComponents(struct xkb_component_names * names,
* as "Ua1b2", and other unknown keysyms as "0xabcd1234".
*
* The string returned may become invalidated after the next call to
* XkbcKeysymToString: if you need to preserve it, then you must
* duplicate it.
*
* This is uint32_t rather than KeySym, as KeySym changes size between
* client and server (no, really).
*/
_X_EXPORT extern char *
-XkbcKeysymToString(uint32_t ks);
+xkb_keysym_to_string(uint32_t ks);
/*
* See XkbcKeysymToString comments: this function will accept any string
* from that function.
*/
_X_EXPORT extern uint32_t
-XkbcStringToKeysym(const char *s);
+xkb_string_to_keysym(const char *s);
_XFUNCPROTOEND
@@ -922,21 +922,21 @@ XkbcCanonicaliseComponents(struct xkb_component_names * names,
*
* The string returned may become invalidated after the next call to
- * XkbcKeysymToString: if you need to preserve it, then you must
+ * xkb_keysym_to_string: if you need to preserve it, then you must
* duplicate it.
*
@@ -922,21 +922,21 @@ XkbcCanonicaliseComponents(struct xkb_component_names * names,
/*
- * See XkbcKeysymToString comments: this function will accept any string
+ * See xkb_keysym_to_string comments: this function will accept any string
* from that function.
*/